package sun.management;

import javax.management.openmbean.OpenDataException;
import javax.management.openmbean.CompositeDataSupport;
import javax.management.openmbean.CompositeData;
import javax.management.openmbean.CompositeType;

public class StackTraceElementCompositeData extends LazyCompositeData
{
    private final StackTraceElement ste;
    private static final CompositeType stackTraceElementCompositeType;
    private static final String CLASS_NAME = "className";
    private static final String METHOD_NAME = "methodName";
    private static final String FILE_NAME = "fileName";
    private static final String LINE_NUMBER = "lineNumber";
    private static final String NATIVE_METHOD = "nativeMethod";
    private static final String[] stackTraceElementItemNames;
    private static final long serialVersionUID = -2704607706598396827L;
    
    private StackTraceElementCompositeData(StackTraceElement ste) {
        this.ste = ste;
    }
    
    public StackTraceElement getStackTraceElement() {
        return this.ste;
    }
    
    public static StackTraceElement from(CompositeData compositeData) {
        validateCompositeData(compositeData);
        return new StackTraceElement(LazyCompositeData.getString(compositeData, "className"), LazyCompositeData.getString(compositeData, "methodName"), LazyCompositeData.getString(compositeData, "fileName"), LazyCompositeData.getInt(compositeData, "lineNumber"));
    }
    
    public static CompositeData toCompositeData(StackTraceElement stackTraceElement) {
        return new StackTraceElementCompositeData(stackTraceElement).getCompositeData();
    }
    
    @Override
    protected CompositeData getCompositeData() {
        Object[] itemValues = { this.ste.getClassName(), this.ste.getMethodName(), this.ste.getFileName(), new Integer(this.ste.getLineNumber()), new Boolean(this.ste.isNativeMethod()) };
        try {
            return new CompositeDataSupport(StackTraceElementCompositeData.stackTraceElementCompositeType, StackTraceElementCompositeData.stackTraceElementItemNames, itemValues);
        }
        catch (OpenDataException detailMessage) {
            throw new AssertionError(detailMessage);
        }
    }
    
    public static void validateCompositeData(CompositeData compositeData) {
        if (compositeData == null) {
            throw new NullPointerException("Null CompositeData");
        }
        if (!LazyCompositeData.isTypeMatched(StackTraceElementCompositeData.stackTraceElementCompositeType, compositeData.getCompositeType())) {
            throw new IllegalArgumentException("Unexpected composite type for StackTraceElement");
        }
        return;
    }
    
    static {
        try {
            stackTraceElementCompositeType = (CompositeType)MappedMXBeanType.toOpenType(StackTraceElement.class);
        }
        catch (OpenDataException detailMessage) {
            throw new AssertionError(detailMessage);
        }
        stackTraceElementItemNames = new String[] { "className", "methodName", "fileName", "lineNumber", "nativeMethod" };
    }
}
